@@ -19,28 +19,26 @@
 using namespace Akregator;
 
 K_PLUGIN_CLASS_WITH_JSON(KCMAkregatorBrowserConfig, "akregator_config_browser.json")
-
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
 KCMAkregatorBrowserConfig::KCMAkregatorBrowserConfig(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
     , m_widget(new QWidget(this))
+#else
+KCMAkregatorBrowserConfig::KCMAkregatorBrowserConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : KCModule(parent, data, args)
+    , m_widget(new QWidget(widget()))
+#endif
 {
     Ui::SettingsBrowser ui;
     ui.setupUi(m_widget);
-
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     auto layout = new QVBoxLayout(this);
+#else
+    auto layout = new QVBoxLayout(widget());
+#endif
     layout->addWidget(m_widget);
 
     connect(ui.kcfg_ExternalBrowserUseCustomCommand, &QAbstractButton::toggled, ui.kcfg_ExternalBrowserCustomCommand, &QWidget::setEnabled);
-    auto about = new KAboutData(QStringLiteral("kcmakrbrowserconfig"),
-                                i18n("Configure Feed Reader Browser"),
-                                QString(),
-                                QString(),
-                                KAboutLicense::GPL,
-                                i18n("(c), 2004 - 2008 Frank Osterfeld"));
-
-    about->addAuthor(i18n("Frank Osterfeld"), QString(), QStringLiteral("osterfeld@kde.org"));
-
-    setAboutData(about);
     addConfig(Settings::self(), m_widget);
 }
 
