@@ -16,24 +16,27 @@
 using namespace Akregator;
 
 K_PLUGIN_CLASS_WITH_JSON(KCMAkregatorPluginsConfig, "akregator_config_plugins.json")
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
 
 KCMAkregatorPluginsConfig::KCMAkregatorPluginsConfig(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
+#else
+KCMAkregatorPluginsConfig::KCMAkregatorPluginsConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : KCModule(parent, data, args)
+
+#endif
 {
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     auto lay = new QHBoxLayout(this);
+#else
+    auto lay = new QHBoxLayout(widget());
+#endif
     lay->setContentsMargins({});
-
-    auto about = new KAboutData(QStringLiteral("kcmakrpluginsconfig"),
-                                i18n("Configure Plugins"),
-                                QString(),
-                                QString(),
-                                KAboutLicense::GPL,
-                                i18n("(c), 2016-2021 Laurent Montel"));
-
-    about->addAuthor(i18n("Laurent Montel"), QString(), QStringLiteral("montel@kde.org"));
-
-    setAboutData(about);
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     mConfigurePluginWidget = new PimCommon::ConfigurePluginsWidget(new AkregatorConfigurePluginListWidget(this), this);
+#else
+    mConfigurePluginWidget = new PimCommon::ConfigurePluginsWidget(new AkregatorConfigurePluginListWidget(widget()), widget());
+#endif
     mConfigurePluginWidget->setObjectName(QStringLiteral("configurePluginWidget"));
     connect(mConfigurePluginWidget, &PimCommon::ConfigurePluginsWidget::changed, this, &KCMAkregatorPluginsConfig::slotConfigChanged);
     lay->addWidget(mConfigurePluginWidget);
@@ -41,7 +44,11 @@ KCMAkregatorPluginsConfig::KCMAkregatorPluginsConfig(QWidget *parent, const QVar
 
 void KCMAkregatorPluginsConfig::slotConfigChanged()
 {
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     Q_EMIT changed(true);
+#else
+    markAsChanged();
+#endif
 }
 
 void KCMAkregatorPluginsConfig::save()
