@@ -5,7 +5,7 @@
 */
 
 #pragma once
-
+#include "kcmutils_version.h"
 #include <KCModule>
 #include <QVariant>
 namespace PimCommon
@@ -19,7 +19,11 @@ class KCMAkregatorPluginsConfig : public KCModule
 {
     Q_OBJECT
 public:
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     explicit KCMAkregatorPluginsConfig(QWidget *parent, const QVariantList &args);
+#else
+    explicit KCMAkregatorPluginsConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
+#endif
     void load() override;
     void save() override;
     void defaults() override;
