@@ -21,24 +21,26 @@
 using namespace Akregator;
 
 K_PLUGIN_CLASS_WITH_JSON(KCMAkregatorUserFeedBackConfig, "akregator_config_userfeedback.json")
-
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
 KCMAkregatorUserFeedBackConfig::KCMAkregatorUserFeedBackConfig(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
+#else
+KCMAkregatorUserFeedBackConfig::KCMAkregatorUserFeedBackConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : KCModule(parent, data, args)
+#endif
 {
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     auto lay = new QHBoxLayout(this);
+#else
+    auto lay = new QHBoxLayout(widget());
+#endif
     lay->setContentsMargins({});
 
-    auto about = new KAboutData(QStringLiteral("kcmaddressbookuserfeedbackconfig"),
-                                i18n("Configure User Feedback"),
-                                QString(),
-                                QString(),
-                                KAboutLicense::GPL,
-                                i18n("(c), 2020-2021 Laurent Montel"));
-
-    about->addAuthor(i18n("Laurent Montel"), QString(), QStringLiteral("montel@kde.org"));
-
-    setAboutData(about);
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     mUserFeedbackWidget = new KUserFeedback::FeedbackConfigWidget(this);
+#else
+    mUserFeedbackWidget = new KUserFeedback::FeedbackConfigWidget(widget());
+#endif
     connect(mUserFeedbackWidget, &KUserFeedback::FeedbackConfigWidget::configurationChanged, this, &KCMAkregatorUserFeedBackConfig::markAsChanged);
 
     lay->addWidget(mUserFeedbackWidget);
