@@ -5,7 +5,7 @@
 */
 
 #pragma once
-
+#include "kcmutils_version.h"
 #include <KCModule>
 
 #include <QVariant>
@@ -20,7 +20,11 @@ class KCMAkregatorUserFeedBackConfig : public KCModule
 {
     Q_OBJECT
 public:
-    KCMAkregatorUserFeedBackConfig(QWidget *parent, const QVariantList &args);
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
+    explicit KCMAkregatorUserFeedBackConfig(QWidget *parent, const QVariantList &args);
+#else
+    explicit KCMAkregatorUserFeedBackConfig(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
+#endif
     void load() override;
     void save() override;
     void defaults() override;
