@@ -9,8 +9,7 @@
 #include "aboutdata.h"
 #include "akregator_debug.h"
 #include "akregator_options.h"
-#include <kcoreaddons_version.h>
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include "akregratormigrateapplication.h"
 #endif
 #include "mainwindow.h"
@@ -33,9 +32,7 @@ public:
     {
     }
 
-    ~Application() override
-    {
-    }
+    ~Application() override = default;
 
     int activate(const QStringList &args, const QString &workingDir) override;
 
@@ -70,8 +67,10 @@ int Application::activate(const QStringList &args, const QString &workingDir)
 int main(int argc, char **argv)
 {
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     Akregator::Application app(argc, &argv);
     KLocalizedString::setApplicationDomain("akregator");
 
@@ -100,7 +99,7 @@ int main(int argc, char **argv)
         qCWarning(AKREGATOR_LOG) << "akregator is already running, exiting.";
         exit(0);
     }
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     AkregratorMigrateApplication migrate;
     migrate.migrate();
 #endif
