@@ -43,9 +43,6 @@ MainWindow::MainWindow(QWidget *parent)
     , m_part()
     , m_statusLabel(new KSqueezedTextLabel(this))
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    setPluginLoadingMode(DoNotLoadPlugins);
-#endif
     // set the shell's ui resource file
     setXMLFile(QStringLiteral("akregator_shell.rc"));
 
@@ -135,7 +132,7 @@ void MainWindow::slotToggleMenubar(bool dontShowWarning)
 
 void MainWindow::updateHamburgerMenu()
 {
-    auto *menu = new QMenu(this);
+    auto menu = new QMenu(this);
     menu->addAction(actionCollection()->action(QLatin1String(KStandardAction::name(KStandardAction::Quit))));
     mHamburgerMenu->setMenu(menu);
 }
