@@ -35,7 +35,11 @@ public:
     {
     }
 
-    enum Column { TitleColumn = 0, UnreadColumn = 1, TotalColumn = 2 };
+    enum Column {
+        TitleColumn = 0,
+        UnreadColumn = 1,
+        TotalColumn = 2,
+    };
 
 public Q_SLOTS:
 
@@ -71,4 +75,3 @@ private:
     QByteArray m_headerState;
 };
 }
-
