@@ -17,18 +17,13 @@
 #include <QMenu>
 #include <QStyleOption>
 
-#include "akregator_debug.h"
 #include <KIO/Global>
 #include <KLocalizedString>
 #include <QTabBar>
 
-#include "actionmanager.h"
 #include "akregatorconfig.h"
 #include "frame.h"
-#include "framemanager.h"
-#include "kernel.h"
 #include "openurlrequest.h"
-#include "utils/temporaryvalue.h"
 
 using namespace Akregator;
 
@@ -491,5 +486,9 @@ void TabWidget::slotCloseRequest(int index)
 
 void TabWidget::slotActivateTab()
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     setCurrentIndex(sender()->objectName().rightRef(2).toInt() - 1);
+#else
+    setCurrentIndex(QStringView(sender()->objectName()).right(2).toInt() - 1);
+#endif
 }
